@@ -7,13 +7,14 @@ describe 'openstack_extras::repo::debian::debian' do
         :manage_deb      => true,
         :source_hash     => {},
         :source_defaults => {},
-        :package_require => false
+        :package_require => false,
+        :use_extrepo     => false,
       }
     end
 
     let :paramclass_defaults do
       {
-        :release => 'ussuri'
+        :release => 'victoria'
       }
     end
 
@@ -21,20 +22,50 @@ describe 'openstack_extras::repo::debian::debian' do
       class_params.merge!(paramclass_defaults)
     end
 
-    context 'with default parameters' do
+    context 'with default params' do
+      it { should contain_exec('/usr/bin/extrepo enable openstack_victoria').with(
+        :command => "/bin/true # comment to satisfy puppet syntax requirements
+apt-get update
+apt-get install -y extrepo
+extrepo enable openstack_victoria
+apt-get update
+",
+      )}
+    end
+
+    context 'wallaby with extrepo' do
       let :params do
-        {}
+        {
+          :release     => 'wallaby',
+          :use_extrepo => true,
+        }
+      end
+      it { should contain_exec('/usr/bin/extrepo enable openstack_wallaby').with(
+        :command => "/bin/true # comment to satisfy puppet syntax requirements
+apt-get update
+apt-get install -y extrepo
+extrepo enable openstack_wallaby
+apt-get update
+",
+      )}
+    end
+
+    context 'with extrepo set to false' do
+      let :params do
+        {
+          :use_extrepo => false,
+        }
       end
 
       it { should contain_apt__source('debian-openstack-backports').with(
-        :location => 'http://stretch-ussuri.debian.net/debian',
-        :release  => 'stretch-ussuri-backports',
+        :location => 'http://stretch-victoria.debian.net/debian',
+        :release  => 'stretch-victoria-backports',
         :repos    => 'main',
       )}
 
       it { should contain_apt__source('debian-openstack-backports-nochange').with(
-        :location => 'http://stretch-ussuri.debian.net/debian',
-        :release  => 'stretch-ussuri-backports-nochange',
+        :location => 'http://stretch-victoria.debian.net/debian',
+        :release  => 'stretch-victoria-backports-nochange',
         :repos    => 'main'
       )}
 
@@ -87,19 +118,20 @@ describe 'openstack_extras::repo::debian::debian' do
                                    }
                                 }
                               })
+        default_params.merge!({ :use_extrepo => false })
       end
 
       it { should contain_apt__source('debian_unstable').with(
-        :location => 'http://mymirror/debian/',
-        :release  => 'unstable',
-        :repos    => 'main'
+        :location    => 'http://mymirror/debian/',
+        :release     => 'unstable',
+        :repos       => 'main',
       )}
 
       it { should contain_apt__source('puppetlabs').with(
-        :location => 'http://apt.puppetlabs.com',
-        :repos    => 'main',
-        :release  => 'stretch',
-        :key      => { 'id' => '4BD6EC30', 'server' => 'pgp.mit.edu' }
+        :location    => 'http://apt.puppetlabs.com',
+        :repos       => 'main',
+        :release     => 'stretch',
+        :key         => { 'id' => '4BD6EC30', 'server' => 'pgp.mit.edu' },
       )}
 
       it { should contain_exec('installing openstack-backports-archive-keyring') }
@@ -119,13 +151,14 @@ describe 'openstack_extras::repo::debian::debian' do
                                    'include' => { 'src' => true }
                                 }
                               })
+        default_params.merge!({ :use_extrepo => false })
       end
 
       it { should contain_apt__source('debian_unstable').with(
-        :include  => { 'src' => true },
-        :location => 'http://mymirror/debian/',
-        :release  => 'unstable',
-        :repos    => 'main',
+        :include     => { 'src' => true },
+        :location    => 'http://mymirror/debian/',
+        :release     => 'unstable',
+        :repos       => 'main',
       )}
 
       it { should contain_exec('installing openstack-backports-archive-keyring') }
